# Tobiko

Tobiko InfraRed Plugin

Tobiko was created for testing OpenStack Upgrades.
You can find the official project right [here](https://github.com/openstack/tobiko)


## Usage

    infrared tobiko --tests neutron
